# equia: Python SDK for accessing Equia API

[![PyPi](https://badge.fury.io/py/equia.svg)](https://pypi.org/project/equia/)

## Table of Contents

- [Overview](#overview)
- [Installation](#installation)
- [Supported Python Versions](#supported-python-versions)
- [License and Terms](#license-and-terms)

## Overview

[Equia](https://vlxe.com/) is the cloud version of VLXE.
It supports all the calculations and systems from the Excel version of VLXE but also much more.
The Equia Python SDK enables access to Equia services from privileged environments
(such as servers or cloud) in Python.

For more information, visit the [Equia product guide](https://vlxe.com).

## Installation

Equia Python SDK releases are available as wheel packages for macOS, Windows and Linux on PyPI. Install it using `pip <https://pypi.org/project/pip/>`\_:

```
pip install equia
pip install aiohttp
pip install matplotlib
pip install pytest-asyncio
```

## Supported Python Versions

We currently support Python 3.6+. Equia
Python SDK is also tested on PyPy environment.

## License and Terms

Equia Python SDK is licensed under the
[Apache License, version 2.0](http://www.apache.org/licenses/LICENSE-2.0).

Your use of Equia is governed by the
[Terms of Service for Equia](https://vlxe.com/).
